bl_info = {
    "name": "New Retopo Object",
    "author": "Xorrito",
    "version": (1, 0),
    "blender": (2, 80, 0),
    "location": "View3D > Add > Mesh > New Object",
    "description": "Adds a new Retopo Object",
    "warning": "",
    "wiki_url": "",
    "category": "Add Mesh",
}


import bpy
from bpy.types import Operator
from bpy.props import FloatVectorProperty
from bpy_extras.object_utils import AddObjectHelper, object_data_add
from mathutils import Vector


def add_object(self, context):
    objeto = bpy.context.selected_objects[0]
    bpy.ops.mesh.primitive_plane_add(size=2, enter_editmode=True, location=(0, 0, 0))
    plane = bpy.context.selected_objects[0]
# change name
    plane.name = "MyLittleRetopo"
    bpy.ops.mesh.delete(type='VERT')
    bpy.context.scene.tool_settings.annotation_stroke_placement_view3d = 'SURFACE'
    bpy.context.scene.bsurfaces.SURFSK_object_with_retopology = bpy.data.objects["MyLittleRetopo"]
    bpy.ops.object.modifier_add(type='SHRINKWRAP')
    bpy.context.object.modifiers["Shrinkwrap"].target = objeto
    bpy.context.object.modifiers["Shrinkwrap"].show_on_cage = True
    bpy.context.object.modifiers["Shrinkwrap"].wrap_mode = 'OUTSIDE'
    bpy.context.object.modifiers["Shrinkwrap"].offset = 0.01
    
    bpy.context.object.display_type = 'SOLID'
    bpy.context.object.color = (1, 0, 0, 1)
    bpy.context.object.color = (1, 0, 0, 1)
    bpy.context.object.show_wire = True

    my_areas = bpy.context.workspace.screens[0].areas
#    my_shading = 'SOLID'
#    my_light = 'MATCAP'
    my_color_type = 'OBJECT'
#    my_show_xray = False
#    my_show_cavity = True
#    my_show_object_outline = False


    def chngviewptshader():
        for area in my_areas:
            for space in area.spaces:
                if space.type == 'VIEW_3D':
                    try:
#                       space.shading.type = my_shading
#                       space.shading.light = my_light
                        space.shading.color_type = my_color_type
#                       space.shading.show_xray = my_show_xray
#                       space.shading.show_cavity = my_show_cavity
#                       space.shading.show_object_outline = my_show_object_outline
                    except:
                        print('Setting invalid')

    chngviewptshader()
    
    
    
#Snap Options    
    
    
    
    bpy.context.scene.tool_settings.snap_elements = {'FACE'}
    bpy.context.scene.tool_settings.use_snap = True
    bpy.context.scene.tool_settings.use_snap_self = False
    bpy.context.scene.tool_settings.use_snap_align_rotation = True
    bpy.context.scene.tool_settings.use_snap_project = True
    bpy.context.scene.tool_settings.use_snap_rotate = True
    bpy.context.scene.tool_settings.use_snap_scale = True

    bpy.context.scene.tool_settings.use_mesh_automerge = True
    bpy.context.scene.tool_settings.double_threshold = 0.01
    
    
    
    mesh = bpy.data.meshes.new(name="Retopo Object")
    
    # useful for development when the mesh may be invalid.
    # mesh.validate(verbose=True)
    object_data_add(context, mesh, operator=self)


class OBJECT_OT_add_object(Operator, AddObjectHelper):
    """Create a new Retopo Object"""
    bl_idname = "mesh.add_object"
    bl_label = "Add Mesh Retopo Object"
    bl_options = {'REGISTER', 'UNDO'}

    scale: FloatVectorProperty(
        name="scale",
        default=(1.0, 1.0, 1.0),
        subtype='TRANSLATION',
        description="scaling",
    )

    def execute(self, context):

        add_object(self, context)

        return {'FINISHED'}


# Registration

def add_object_button(self, context):
    self.layout.operator(
        OBJECT_OT_add_object.bl_idname,
        text="Add Retopo Object",
        icon='PLUGIN')


# This allows you to right click on a button and link to the manual
def add_object_manual_map():
    url_manual_prefix = "https://docs.blender.org/manual/en/dev/"
    url_manual_mapping = (
        ("bpy.ops.mesh.add_object", "editors/3dview/object"),
    )
    return url_manual_prefix, url_manual_mapping


def register():
    bpy.utils.register_class(OBJECT_OT_add_object)
    bpy.utils.register_manual_map(add_object_manual_map)
    bpy.types.VIEW3D_MT_mesh_add.append(add_object_button)


def unregister():
    bpy.utils.unregister_class(OBJECT_OT_add_object)
    bpy.utils.unregister_manual_map(add_object_manual_map)
    bpy.types.VIEW3D_MT_mesh_add.remove(add_object_button)


if __name__ == "__main__":
    register()
